+++
title = "Imprint"
description = "Imprint information"
date = "2019-08-07"
author = "Christian Decker"
+++

Information according to § 5 TMG

_first and last name_     
_address_

#### Contact:
Phone: _phone number_     
E-Mail: _e-mail address_

#### Responsible for content according to § 55 Abs. 2 RStV:

_first and last name_     
_address_

#### Disclaimer:

#### Content Liability

The contents of our pages were created with great care. However, we can not assume any liability for the accuracy, completeness and timeliness of the content. As a service provider we are responsible according to § 7 Abs.1 TMG for own contents on these sides according to the general laws. According to §§ 8 to 10 TMG, however, we as a service provider are not obliged to monitor transmitted or stored external information or to investigate circumstances that indicate illegal activity. Obligations to remove or block the use of information under general law remain unaffected. A liability in this regard, however, is only possible from the date of knowledge of a specific infringement. Upon notification of such violations, we will remove this content immediately.

#### Liability for links

Our offer contains links to external websites of third parties on whose contents we have no influence. Therefore, we can not assume any liability for these external contents. The respective provider or operator of the pages is always responsible for the contents of the linked pages. The linked pages were checked for possible legal violations at the time of linking. Illegal content was not recognizable at the time of linking. However, a permanent content control of the linked pages is not reasonable without concrete evidence of an infringement. Upon notification of violations, we will remove such links immediately.

#### Copyright

The content and works on these pages created by the site operators are subject to German copyright law. The reproduction, processing, distribution and any kind of exploitation outside the limits of copyright require the written consent of the respective author or creator. Downloads and copies of this site are for private, non-commercial use only. As far as the contents on this side were not created by the operator, the copyrights of third parties are considered. In particular contents of third parties are marked as such. If you should still be aware of a copyright infringement, we ask for a note. Upon discovery of violations, we will remove such content immediately.

#### Privacy Policy

The use of our website is usually possible without providing personal information. As far as on our sides personal data (for example name, address or eMail addresses) are raised, this takes place, as far as possible, always on freiwilliger basis. These data will not be disclosed to third parties without your explicit consent.
Please note that data transmission over the Internet (for example, when communicating via e-mail) may have security vulnerabilities. A complete protection of the data from access by third parties is not possible.
The use of contact data published in the context of the imprint obligation by third parties for sending unsolicited advertising and information materials is hereby expressly excluded. The operators of the pages expressly reserve the right to take legal action in case of unsolicited promotional information, such as spam e-mails.

Website Imprint generated by [impressum-generator.de](http://www.impressum-generator.de/) and afterwards translated using Google Translate. 
